"use client";
import { useState } from "react";
import DataTable from "@/components/tables/DataTable";
import { columnsDataBlocks } from "../variables/columnsBlock";
import { TableData } from "@/variables/columnsData";
import AddButton from "@/components/buttons/add";
import { EditIcon, DeleteIcon } from "@chakra-ui/icons";
import { Flex, Button, Icon, useColorModeValue } from "@chakra-ui/react";
import { deleteRole } from "@/app/lib/role/action";
import useShowToast from "@/app/hooks/useShowToast";
import { useRouter } from "next/navigation";
import { hasPermission } from "@/utils/navigation";
import { useGeneral } from "@/contexts/GeneralContext";

export interface Role {
  id: number;
  name: string;
}

interface RolesTableProps {
  roles: Role[];
}

const RolesTable: React.FC<RolesTableProps> = ({ roles }) => {
  const { currentUser } = useGeneral();
  const brandColor = useColorModeValue("brand.500", "white");
  const router = useRouter();
  const showToast = useShowToast();
  const [loading, setLoading] = useState<number | null>(null);
  const handleAdd = () => {
    router.push('/admin/roles/create')
  };

  const handleEdit = (id: number) => {
    router.push(`/admin/roles/edit/${id}`)
  };

  const handleDelete = async (id: number) => {
    setLoading(id);
    try {
      const response = await deleteRole(id);
      if (response.status === false) {
        throw new Error(response.message || "Failed to delete role.");
      }
      showToast("Role Deleted!", response.message, "success");
      router.refresh();
    } catch (error: any) {
      showToast("Failed to delete", error.message, "error");
    } finally {
      setLoading(null);
    }
  };
  const actions = (id: number) => (
    <Flex gap={2}>
      {hasPermission(currentUser.permissions, "role", "edit") && (
        <Button
          variant="blank"
          alignItems="center"
          justifyContent="center"
          w="24px"
          h="24px"
          lineHeight="100%"
          borderRadius="10px"
          minW={0}
          onClick={() => {
            handleEdit(id);
          }}
          isDisabled={!hasPermission(currentUser.permissions, "role", "edit")}
        >
          <Icon as={EditIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}

      {hasPermission(currentUser.permissions, "role", "delete") && (
        <Button
          variant="blank"
          alignItems="center"
          justifyContent="center"
          w="24px"
          h="24px"
          lineHeight="100%"
          borderRadius="10px"
          minW={0}
          onClick={() => {
            handleDelete(id);
          }}
          isDisabled={loading === id}
        >
          <Icon as={DeleteIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}

    </Flex>
  );
  return (
    <DataTable
      columnsData={columnsDataBlocks}
      tableData={roles as unknown as TableData[]}
      isSelectable={false}
      showPageSize={false}
      addButton={hasPermission(currentUser.permissions, "role", "create") && <AddButton onClick={handleAdd} isDisabled={!hasPermission(currentUser.permissions, "role", "create")} />}
      actionSlot={actions}
    />
  );
};

export default RolesTable;
